package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabViolationScoreSite;
import com.zd.laboratory.service.ILabViolationScoreSiteService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.zd.common.core.web.page.TableDataInfo;

/**
 * 违规项扣分设置Controller
 *
 * @author zd
 * @date 2021-12-13
 */
@RestController
@Api(tags = "【违规项扣分设置】")
//作者手动加入 ，在接口上加作者@ApiOperationSupport(author = "XXX")
@RequestMapping("/violationScoreSite")
public class LabViolationScoreSiteController extends BaseController
{
    @Autowired
    private ILabViolationScoreSiteService labViolationScoreSiteService;

    /**
     * 查询违规项扣分设置列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONSCORESITE + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询违规项扣分设置列表")
    public TableDataInfo<LabViolationScoreSite> list(LabViolationScoreSite labViolationScoreSite)
    {
        startPage();
        List<LabViolationScoreSite> list = labViolationScoreSiteService.selectLabViolationScoreSiteList(labViolationScoreSite);
        return getDataTable(list);
    }

    /**
     * 导出违规项扣分设置列表
     */
    @ApiOperation(value = "导出违规项扣分设置列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONSCORESITE + PerFun.EXPORT)
    @Log(title = "违规项扣分设置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabViolationScoreSite labViolationScoreSite) throws IOException
    {
        List<LabViolationScoreSite> list = labViolationScoreSiteService.selectLabViolationScoreSiteList(labViolationScoreSite);
        ExcelUtil<LabViolationScoreSite> util = new ExcelUtil<LabViolationScoreSite>(LabViolationScoreSite.class);
        util.exportExcel(response, list, "违规项扣分设置数据");
    }

    /**
     * 获取违规项扣分设置详细信息
     */
    @ApiOperation(value = "获取违规项扣分设置详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONSCORESITE + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabViolationScoreSite> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(labViolationScoreSiteService.selectLabViolationScoreSiteById(id));
    }

    /**
     * 新增违规项扣分设置
     */
    @ApiOperation(value = "新增违规项扣分设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONSCORESITE + PerFun.ADD)
    @Log(title = "违规项扣分设置", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabViolationScoreSite labViolationScoreSite)
    {
        return ResultData.result(labViolationScoreSiteService.insertLabViolationScoreSite(labViolationScoreSite));
    }

    /**
     * 修改违规项扣分设置
     */
    @ApiOperation(value = "修改违规项扣分设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONSCORESITE + PerFun.EDIT)
    @Log(title = "违规项扣分设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabViolationScoreSite labViolationScoreSite)
    {
        return  ResultData.result(labViolationScoreSiteService.updateLabViolationScoreSite(labViolationScoreSite));
    }

    /**
     * 删除违规项扣分设置
     */
    @ApiOperation(value = "删除违规项扣分设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONSCORESITE + PerFun.REMOVE)
    @Log(title = "违规项扣分设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(labViolationScoreSiteService.deleteLabViolationScoreSiteByIds(ids));
    }


    /**
     * 查询违规项字典列表
     */
    @GetMapping("/getDictViolation")
    @ApiOperation(value = "查询违规项扣分设置列表")
    public AjaxResult getDictViolation()
    {
        List<LabViolationScoreSite> list = labViolationScoreSiteService.selectLabScoreSiteList();
        return AjaxResult.success(list);
    }
}
